summaryrefslogtreecommitdiff
path: root/locks/beos
diff options
context:
space:
mode:
authorronald <ronald@13f79535-47bb-0310-9956-ffa450edef68>2000-03-10 04:15:40 +0000
committerronald <ronald@13f79535-47bb-0310-9956-ffa450edef68>2000-03-10 04:15:40 +0000
commitc09d17c6b4865a1c1918088e59b56c49274cb990 (patch)
tree843af930854317acabc4bca4a9eb15e8820884f7 /locks/beos
parent8a04f79b1b123f3e5aed1d9208134ca58e21246a (diff)
downloadlibapr-c09d17c6b4865a1c1918088e59b56c49274cb990.tar.gz
changed erroneous references to type to scope; added scope to lock_t
git-svn-id: http://svn.apache.org/repos/asf/apr/apr/trunk@59690 13f79535-47bb-0310-9956-ffa450edef68
Diffstat (limited to 'locks/beos')
-rw-r--r--locks/beos/locks.c19
-rw-r--r--locks/beos/locks.h3
2 files changed, 12 insertions, 10 deletions
diff --git a/locks/beos/locks.c b/locks/beos/locks.c
index df7df6f9e..1f252f1bb 100644
--- a/locks/beos/locks.c
+++ b/locks/beos/locks.c
@@ -68,15 +68,16 @@ ap_status_t ap_create_lock(struct lock_t **lock, ap_locktype_e type,
}
new->cntxt = cont;
- new->type = type;
+ new->type = type;
+ new->scope = scope;
new->fname = ap_pstrdup(cont, fname);
- if (type != APR_CROSS_PROCESS) {
+ if (scope != APR_CROSS_PROCESS) {
if ((stat = create_intra_lock(new)) != APR_SUCCESS) {
return stat;
}
}
- if (type != APR_INTRAPROCESS) {
+ if (scope != APR_INTRAPROCESS) {
if ((stat = create_inter_lock(new)) != APR_SUCCESS) {
return stat;
}
@@ -89,12 +90,12 @@ ap_status_t ap_lock(ap_lock_t *lock)
{
ap_status_t stat;
- if (lock->type != APR_CROSS_PROCESS) {
+ if (lock->scope != APR_CROSS_PROCESS) {
if ((stat = lock_intra(lock)) != APR_SUCCESS) {
return stat;
}
}
- if (lock->type != APR_INTRAPROCESS) {
+ if (lock->scope != APR_INTRAPROCESS) {
if ((stat = lock_inter(lock)) != APR_SUCCESS) {
return stat;
}
@@ -105,12 +106,12 @@ ap_status_t ap_lock(ap_lock_t *lock)
ap_status_t ap_unlock(ap_lock_t *lock)
{
ap_status_t stat;
- if (lock->type != APR_CROSS_PROCESS) {
+ if (lock->scope != APR_CROSS_PROCESS) {
if ((stat = unlock_intra(lock)) != APR_SUCCESS) {
return stat;
}
}
- if (lock->type != APR_INTRAPROCESS) {
+ if (lock->scope != APR_INTRAPROCESS) {
if ((stat = unlock_inter(lock)) != APR_SUCCESS) {
return stat;
}
@@ -121,12 +122,12 @@ ap_status_t ap_unlock(ap_lock_t *lock)
ap_status_t ap_destroy_lock(ap_lock_t *lock)
{
ap_status_t stat;
- if (lock->type != APR_CROSS_PROCESS) {
+ if (lock->scope != APR_CROSS_PROCESS) {
if ((stat = destroy_intra_lock(lock)) != APR_SUCCESS) {
return stat;
}
}
- if (lock->type != APR_INTRAPROCESS) {
+ if (lock->scope != APR_INTRAPROCESS) {
if ((stat = destroy_inter_lock(lock)) != APR_SUCCESS) {
return stat;
}
diff --git a/locks/beos/locks.h b/locks/beos/locks.h
index 092c7bb11..b2557a4d6 100644
--- a/locks/beos/locks.h
+++ b/locks/beos/locks.h
@@ -64,6 +64,7 @@
struct lock_t {
ap_context_t *cntxt;
ap_locktype_e type;
+ ap_lockscope_e scope;
int curr_locked;
char *fname;
/* Inter proc */
@@ -72,7 +73,7 @@ struct lock_t {
/* Intra Proc */
sem_id sem_intraproc;
int32 ben_intraproc;
/* At some point, we should do a type for both inter and intra process
* locking here. Something like pthread_mutex with PTHREAD_PROCESS_SHARED
*/
};
@@ -72,7 +73,7 @@ struct lock_t {
sem_id sem_intraproc;
int32 ben_intraproc;
- /* At some point, we should do a type for both inter and intra process
+ /* At some point, we should do a scope for both inter and intra process
* locking here. Something like pthread_mutex with PTHREAD_PROCESS_SHARED
*/